@@ -4,6 +4,7 @@ import os
 import pathlib
 import logging
 import functools
+from .uwDeclare import uwDeclare as ud
 from .uwException import * 
 
 class cmnConfigBase():
@@ -181,7 +182,7 @@ class cmnConfig(cmnConfigBase):
 
                 self.SmtpPort = '587'
                 """ 送信サーバーポート番号 """
-    
+
     class startupConfig(cmnConfigBase):
         
         """
@@ -221,6 +222,9 @@ class cmnConfig(cmnConfigBase):
         self.LogFileName = 'default.log'
         """ ログファイル名 """
 
+        self.LogFileNameSuffix:int = ud.logFileNameSuffix.suffixNone
+        """ ログファイル名サフィックス """
+
         self.LogFolderName = 'log'
         """ ログ出力先フォルダ名 """
 
@@ -376,6 +380,8 @@ class cmnConfig(cmnConfigBase):
         
         # ログファイル名
         self.setConfigValue('LogFileName', self.config_ini,'DEFAULT','LOGFILE_NAME', str)
+        # ログファイル名サフィックス
+        self.setConfigValue('LogFileNameSuffix', self.config_ini,'DEFAULT','LOGFILE_NAME_SUFFIX', int)
         # ログファイル格納先ディレクトリ
         self.setConfigValue('LogFolderName', self.config_ini,'DEFAULT','LOGFOLDER_NAME', str)
         # ログフォーマット
