@@ -798,7 +798,7 @@ class recset(Generic[T]):
         # 結果を返す
         return len(q) > 0
 
-    def merge(self, srcRecset):
+    def merge(self, srcRecset, sort = True):
         
         """
         レコードセットをマージする
@@ -815,14 +815,15 @@ class recset(Generic[T]):
         
         # rows⇒dict変換
         dictrows = dict()
-        for row in self.__rows:
-            
-            # tupleに変換(dictrowのKeyにする)
-            pKeyTuple = self.__getKeyTuple(row)
-            
-            # rowをdictrowsにセット
-            if not pKeyTuple in dictrows:
-                dictrows[pKeyTuple] = row
+        if sort:
+            for row in self.__rows:
+                
+                # tupleに変換(dictrowのKeyにする)
+                pKeyTuple = self.__getKeyTuple(row)
+                
+                # rowをdictrowsにセット
+                if not pKeyTuple in dictrows:
+                    dictrows[pKeyTuple] = row
             
         # マージ対象レコードセットをrowsに追加
         for mergeRow in srcRecset.rows:
@@ -836,19 +837,33 @@ class recset(Generic[T]):
 
         # dictrowsをソート
         rows_sorted = sorted(dictrows.items())
+
+        if sort:
         
-        # rows再構築
-        self.__rows.clear()
-        for row in rows_sorted:
-            self.__rows.append(row[1])
-        
-        # dfrows再構築
-        self.__dfrows = self.__dfrows.drop(range(len(self.__dfrows)))
-        rowIndex = 0
-        for row in rows_sorted:
-            self.__addRecrowDataFrame(row[1], rowIndex)
-            rowIndex += 1
+            # rows再構築
+            self.__rows.clear()
+            for row in rows_sorted:
+                self.__rows.append(row[1])
         
+            # dfrows再構築
+            self.__dfrows = self.__dfrows.drop(range(len(self.__dfrows)))
+            rowIndex = 0
+            for row in rows_sorted:
+                self.__addRecrowDataFrame(row[1], rowIndex)
+                rowIndex += 1
+                
+        else:
+            
+            # rows追加
+            for row in rows_sorted:
+                self.__rows.append(row[1])
+                
+            # dfrows追加
+            rowIndex = len(self.__dfrows)
+            for row in rows_sorted:
+                self.__addRecrowDataFrame(row[1], rowIndex)
+                rowIndex += 1
+
         # fields再構築
         self.__fields = fields(self.__rows, self.__dfrows)
     
